floateditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# floateditor

class `camelot.view.controls.editors.floateditor.` `CustomDoubleSpinBox`(option=None, parent=None)

  Spinbox that doesn’t accept mouse scrolling as input

class `camelot.view.controls.editors.floateditor.` `FloatEditor`(parent, minimum=-1000000000000000.0, maximum=1000000000000000.0, calculator=True, decimal=False, option=None, field_name='float', **kwargs)

  Widget for editing a float field, with a calculator button. The calculator button can be turned of with the calculator field attribute.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus